# titanic-pp-py

This is a work in progress pp system, with the goal of balancing performance points for the relax/autopilot mods with vanilla.
The actual code for this can be viewed [here](https://github.com/osuTitanic/titanic-pp-rs).

You can install this package using this command:

```shell
pip install git+https://github.com/osuTitanic/titanic-pp-py.git
```

Please view the original fork [here](https://github.com/MaxOhn/rosu-pp-py), for general usage.
